/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.portal.rss.blacklist;

import java.util.Collection;

/**
 * Interface representing a generic blacklist.
 *
 * @author Anders Asplund
 *
 * @param <T>
 */
public interface BlackList<T> {

    /**
     * Add an item.
     *
     * @param item the item
     */
    void add(T item);

    /**
     * Remove an item.
     *
     * @param item the item
     */
    void remove(T item);

    /**
     * Whether the item is contained in the object instance.
     *
     * @param item the item
     * @return <code>true</code> if the object contains the item or <code>false</code> otherwise
     */
    boolean contains(T item);

    /**
     * Clear/reset the object instance.
     */
    void clear();

    /**
     * Get the items as a {@link Collection}.
     *
     * @return the items as a {@link Collection}
     */
    Collection<T> items();
}
