/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.portal.rss.blacklist;

import java.util.Collection;
import java.util.Collections;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;

/**
 * A thread-safe implementation of {@link BlackList}.
 *
 * @author Anders Asplund
 *
 * @param <T>
 */
public class ConcurrentBlackList<T> implements BlackList<T> {

    private final Set<T> blackList = Collections.newSetFromMap(new ConcurrentHashMap<T, Boolean>());

    /**
     * {@inheritDoc}
     */
    public void add(T feed) {
        blackList.add(feed);
    }

    /**
     * {@inheritDoc}
     */
    public void remove(T feed) {
        blackList.remove(feed);
    }

    /**
     * {@inheritDoc}
     */
    public boolean contains(T feed) {
        return blackList.contains(feed);
    }

    /**
     * {@inheritDoc}
     */
    public void clear() {
        blackList.clear();
    }

    /**
     * {@inheritDoc}
     */
    public Collection<T> items() {
        return Collections.unmodifiableSet(blackList);
    }
}
