/**
 * Copyright 2010 Västra Götalandsregionen
 *
 *   This library is free software; you can redistribute it and/or modify
 *   it under the terms of version 2.1 of the GNU Lesser General Public
 *   License as published by the Free Software Foundation.
 *
 *   This library is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU Lesser General Public License for more details.
 *
 *   You should have received a copy of the GNU Lesser General Public
 *   License along with this library; if not, write to the
 *   Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 *   Boston, MA 02111-1307  USA
 */

package se.vgregion.portal.rss.blacklist;

import java.net.ConnectException;
import java.net.URL;
import java.util.TimerTask;

import org.rometools.fetcher.FeedFetcher;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * BlackListCleanup is a {@link TimerTask} which can be scheduled to run on repeated intervals. Its purpose is to
 * go through a {@link BlackList} with feed url:s and control if the url can be "whitelisted" again.
 * 
 * @author Anders Asplund
 * 
 */
public class FeedBlackListCleaner extends TimerTask {

    private static final Logger LOG = LoggerFactory.getLogger(FeedBlackListCleaner.class);

    private BlackList<String> blackList;
    private final FeedFetcher feedFetcher;

    /**
     * Constructs an instance of the {@link TimerTask} BlackListCleanup.

     * @param feedFetcher the feedFetcher
     * @param blackList the blackList
     */
    public FeedBlackListCleaner(FeedFetcher feedFetcher, BlackList<String> blackList) {
        this.feedFetcher = feedFetcher;
        this.blackList = blackList;
    }

    @Override
    public void run() {
        for (String feedLink : blackList.items()) {
            try {
                feedFetcher.retrieveFeed(new URL(feedLink));
                blackList.remove(feedLink);
                LOG.info("Remove {} from BlackList", feedLink);
            } catch (ConnectException e) {
                LOG.info("{} will stay on BlackList", feedLink);
            } catch (Exception e) {
                blackList.remove(feedLink);
                LOG.info("Remove {} from BlackList", feedLink);
            }
        }
    }
}
